# Generated by Django 4.0.8 on 2022-12-07 14:46

from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0043_priceconfig_eve_market_group_alter_priceconfig_price'),
    ]

    operations = [
        migrations.AddField(
            model_name='priceconfig',
            name='minimum',
            field=models.DecimalField(decimal_places=2, default=Decimal('0'), help_text='Minimum isk to consider an order at', max_digits=15, verbose_name='Price'),
        ),
    ]
