# Generated by Django 4.0.3 on 2022-03-21 14:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0027_managedwatchconfig_remove_watchconfig_managed_app_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='managedwatchconfig',
            old_name='manged_app_reason',
            new_name='managed_app_reason',
        ),
    ]
