# Generated by Django 4.0.6 on 2022-08-06 06:35

from decimal import Decimal

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0032_alter_watchconfig_managed_watch_config'),
    ]

    operations = [
        migrations.AlterField(
            model_name='managedwatchconfig',
            name='managed_jita_compare_percent',
            field=models.DecimalField(decimal_places=0, default=Decimal('0'), help_text='If set ignores Flat price value', max_digits=4, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(1000)], verbose_name='Jita Comparison %'),
        ),
    ]
