# Generated by Django 4.0.3 on 2022-03-14 12:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0005_alter_watchconfig_constellation_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='watchconfig',
            name='config_type',
            field=models.CharField(choices=[('Supply', 'Supply Check'), ('Bargain', 'Bargain Finder'), ('Scalp', 'Scalp Finder')], default='Supply', help_text='The type of WatchConfig, check documentation for more.', max_length=10, verbose_name='Config Type'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='webhooks',
            field=models.ManyToManyField(blank=True, to='marketmanager.webhook', verbose_name='Webhooks'),
        ),
    ]
