# Generated by Django 4.0.6 on 2022-08-06 07:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0035_alter_watchconfig_jita_compare_percent'),
    ]

    operations = [
        migrations.AddField(
            model_name='watchconfig',
            name='last_result_volume',
            field=models.IntegerField(blank=True, help_text='The Volume returned the last time this WatchConfig was run', null=True, verbose_name='Last Result Volume'),
        ),
        migrations.AddField(
            model_name='watchconfig',
            name='last_run',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Last Task Runtime'),
        ),
    ]
