# Generated by Django 3.2.8 on 2021-12-01 15:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0006_auto_20211201_1343'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='is_buy_order',
            field=models.BooleanField(db_index=True, default=False, help_text='True if the order is a bid (buy) order', verbose_name='Buy Order'),
        ),
    ]
