# Generated by Django 4.0.3 on 2022-03-14 12:32

from decimal import Decimal

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0003_rename_type_watchconfig_eve_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='watchconfig',
            name='jita_compare_percent',
            field=models.DecimalField(decimal_places=0, default=Decimal('0'), help_text='If set ignores Flat price value', max_digits=3, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name='Jita Comparison %'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='price',
            field=models.IntegerField(default=0, help_text='Set to Zero to skip this filter', verbose_name='Price'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='volume',
            field=models.IntegerField(default=1, help_text='Set to Zero to check ANY/EVERY order against Price', verbose_name='Volume'),
        ),
    ]
