# Generated by Django 4.0.3 on 2022-03-13 12:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0009_rename_config_publicconfig_order_source_character_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='source_private',
            field=models.BooleanField(default=False, verbose_name='Sourced From Public Market Data'),
        ),
    ]
