# Generated by Django 4.0.8 on 2023-01-11 03:22

from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0044_priceconfig_minimum'),
    ]

    operations = [
        migrations.AlterField(
            model_name='priceconfig',
            name='minimum',
            field=models.DecimalField(decimal_places=2, default=Decimal('1000000'), help_text='Minimum isk to consider an order at, Default: 1M', max_digits=15, verbose_name='Minimum Price'),
        ),
    ]
