# Generated by Django 4.0.8 on 2022-12-07 06:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0007_evetype_description'),
        ('marketmanager', '0041_alter_general_options_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='priceconfig',
            name='buy_order',
            field=models.BooleanField(default=False, verbose_name='Buy Order'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='eve_group',
            field=models.ManyToManyField(blank=True, to='eveuniverse.evegroup', verbose_name='EVE Inventory Group'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='eve_type',
            field=models.ManyToManyField(blank=True, to='eveuniverse.evetype', verbose_name='EVE Type'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='scalp',
            field=models.BooleanField(default=False, help_text='True for Scalp, False for Bargain', verbose_name='Scalp Finder?'),
        ),
    ]
