# Generated by Django 4.0.3 on 2022-03-15 13:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0012_remove_watchconfig_constellation'),
    ]

    operations = [
        migrations.AddField(
            model_name='watchconfig',
            name='managed_app',
            field=models.CharField(default='', help_text='The App managing this WatchConfig', max_length=50, verbose_name='Managed By App'),
        ),
        migrations.AddField(
            model_name='watchconfig',
            name='managed_app_identifier',
            field=models.CharField(default='', help_text='An identifier relevant to the App managing this WatchConfig', max_length=50, verbose_name='Managed App-Identifier'),
        ),
        migrations.AddField(
            model_name='watchconfig',
            name='manged_app_reason',
            field=models.CharField(default='', help_text='User Facing reason for this Managed WatchConfig', max_length=50, verbose_name='Managed App Reason'),
        ),
    ]
