{% extends "allianceauth/base-bs5.html" %}
{% load i18n %}
{% load humanize %}
{% load static %}

{% block page_title %}
    {% translate "Market Manager" %}
{% endblock page_title %}

{% block header_nav_brand %}
    {% translate "Market Manager" %}
{% endblock header_nav_brand %}

{% block header_nav_collapse_left %}
    <ul class="nav-item">
        {% include "marketmanager/marketbrowser/search-bs5.html" %}
    </ul>
    <ul class="nav-item dropdown">
        {% include "marketmanager/marketbrowser/region_selector-bs5.html" %}
    </ul>
{% endblock header_nav_collapse_left %}

{% block header_nav_collapse_right %}
    <li class="nav-item">
        <a href="{% url 'marketmanager:add_char' %}" class="nav-link">{% translate "Add Character Token" %}</a>
    </li>
    <li class="nav-item">
        <a href="{% url 'marketmanager:add_corp' %}" class="nav-link">{% translate "Add Corporate Token" %}</a>
    </li>
    <li class="nav-item">
        <a href="{% url 'marketmanager:marketwatches' %}" class="nav-link">{% translate "Market Watch Status" %}</a>
    </li>
{% endblock header_nav_collapse_right %}

{% block content %}
{% endblock content %}

{% block extra_javascript %}
    {% include "bundles/datatables-js-bs5.html" %}
    {% include "bundles/jquery-ui-js.html" %}
    {% include "bundles/moment-js.html" %}
{% endblock extra_javascript %}

{% block extra_css %}
    {% include "bundles/datatables-css-bs5.html" %}
    {% include "bundles/jquery-ui-css.html" %}
    <link rel="stylesheet" type="text/css" href="{% static 'marketmanager/css/marketmanager.css' %}" />
{% endblock extra_css %}
