# Generated by Django 4.0.3 on 2022-03-15 13:09

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0011_rename_location_watchconfig_structure'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='watchconfig',
            name='constellation',
        ),
    ]
