# Generated by Django 4.0.6 on 2022-10-22 06:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0039_alter_order_state'),
    ]

    operations = [
        migrations.RenameModel('ManagedWatchConfig', 'ManagedSupplyConfig'),
        migrations.RenameModel('WatchConfig', 'SupplyConfig')
    ]
