# Generated by Django 4.0.10 on 2023-08-04 04:28

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0007_evetype_description'),
        ('marketmanager', '0046_alter_managedsupplyconfig_options_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='structure',
            name='eve_type',
            field=models.ForeignKey(limit_choices_to={'eve_group__id__in': [15, 1657], 'published': 1}, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveuniverse.evetype', verbose_name='Type'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='eve_type',
            field=models.ForeignKey(limit_choices_to={'eve_market_group__isnull': False, 'published': 1}, on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evetype', verbose_name='EVE Type'),
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='eve_region',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.everegion', verbose_name='Region'),
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='eve_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evetype', verbose_name='Type'),
        ),
    ]
