# Generated by Django 4.0.3 on 2022-03-15 14:29

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0005_type_materials_and_sections'),
        ('marketmanager', '0014_alter_watchconfig_price_typestatistics'),
    ]

    operations = [
        migrations.AddField(
            model_name='typestatistics',
            name='eve_region',
            field=models.ForeignKey(default='', on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.everegion', verbose_name=''),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='buy_5_percent',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Buy 5th Percentile'),
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='buy_median',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Buy Median'),
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='buy_weighted_average',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Buy Weighted Average'),
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='eve_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evetype', verbose_name=''),
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='sell_5_percent',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Sell 5th Percentile'),
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='sell_median',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Sell Median'),
        ),
        migrations.AlterField(
            model_name='typestatistics',
            name='sell_weighted_average',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Sell Weighted Average'),
        ),
        migrations.AddConstraint(
            model_name='typestatistics',
            constraint=models.UniqueConstraint(fields=('eve_type', 'eve_region'), name='EveTypeEveRegionTypeStatistic'),
        ),
    ]
