# Generated by Django 4.0.3 on 2022-03-21 14:04

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0026_alter_publicconfig_options_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ManagedWatchConfig',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('managed_app', models.CharField(blank=True, default='', help_text='The App managing this WatchConfig', max_length=50, verbose_name='Managed By App')),
                ('managed_app_identifier', models.CharField(blank=True, default='', help_text='An identifier relevant to the App managing this WatchConfig', max_length=50, verbose_name='Managed App-Identifier')),
                ('manged_app_reason', models.CharField(blank=True, default='', help_text='User Facing reason for this Managed WatchConfig', max_length=50, verbose_name='Managed App Reason')),
            ],
            options={
                'default_permissions': (),
            },
        ),
        migrations.RemoveField(
            model_name='watchconfig',
            name='managed_app',
        ),
        migrations.RemoveField(
            model_name='watchconfig',
            name='managed_app_identifier',
        ),
        migrations.RemoveField(
            model_name='watchconfig',
            name='manged_app_reason',
        ),
        migrations.AddField(
            model_name='watchconfig',
            name='managed_watch_config',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='marketmanager.managedwatchconfig', verbose_name=''),
        ),
    ]
