# Generated by Django 3.2.8 on 2021-11-30 12:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0003_alter_general_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='wallet_division',
            field=models.PositiveSmallIntegerField(blank=True, help_text='The corporation wallet division used for this order.', null=True, verbose_name='Wallet Division'),
        ),
    ]
