{% load i18n %}
{% load humanize %}
<div class="card mb-2">
    <div class="card-header">
        <h4 class="card-title">{% translate "Sell Orders" %}</h4>
    </div>
    <div class="card-body">
        <table class="table table-hover" id="table-sell-orders">
            <thead>
                <tr>
                    <th class="text-left">{% translate "Region" %}</th>
                    <th class="text-left">{% translate "Quantity" %}</th>
                    <th class="text-left">{% translate "Price" %}</th>
                    <th class="text-left">{% translate "Location" %}</th>
                    <th class="text-left">{% translate "Expires" %}</th>
                    <th class="text-left">{% translate "Last Updated" %}</th>
                </tr>
            </thead>
        </table>
        <p class="text-info">{% translate "Owned Character Orders" %}</p>
        <p class="text-success">{% translate "Owned Corporation Orders" %}</p>
    </div>
</div>
