# Generated by Django 4.0.8 on 2022-12-07 12:42

from decimal import Decimal

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0007_evetype_description'),
        ('marketmanager', '0042_alter_priceconfig_buy_order_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='priceconfig',
            name='eve_market_group',
            field=models.ManyToManyField(blank=True, to='eveuniverse.evemarketgroup', verbose_name='EVE Market Group'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='price',
            field=models.DecimalField(decimal_places=2, default=Decimal('0'), help_text='WARNING: Use Jita% when possible, this sets a flat price for ALL items included in this Config. Possibly useful for Caps/Soups', max_digits=15, verbose_name='Price'),
        ),
    ]
