# Generated by Django 4.0.3 on 2022-03-15 04:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0008_alter_general_options'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='watchconfig',
            name='fail_webhooks',
        ),
        migrations.RemoveField(
            model_name='watchconfig',
            name='success_webhooks',
        ),
        migrations.AddField(
            model_name='watchconfig',
            name='debug_webhooks',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on WatchConfigs that dont have any issues', related_name='debug_webhooks', to='marketmanager.webhook', verbose_name='Debug Webhook'),
        ),
        migrations.AddField(
            model_name='watchconfig',
            name='webhooks',
            field=models.ManyToManyField(blank=True, to='marketmanager.webhook', verbose_name='Webhooks'),
        ),
    ]
