# Generated by Django 4.0.8 on 2023-01-30 12:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0045_alter_priceconfig_minimum'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='managedsupplyconfig',
            options={'default_permissions': (), 'verbose_name': 'Managed Supply Config'},
        ),
        migrations.AlterModelOptions(
            name='privateconfig',
            options={'default_permissions': (), 'verbose_name': 'Private Market Configuration'},
        ),
    ]
