# Generated by Django 4.0.6 on 2022-08-02 11:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0030_channel_managedwatchconfig_managed_channels_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='channel',
            name='name',
            field=models.CharField(max_length=100, verbose_name='Name'),
        ),
    ]
