# Generated by Django 4.0 on 2023-10-31 14:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0010_alter_eveindustryactivityduration_eve_type_and_more'),
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        ('marketmanager', '0049_alter_general_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='managedsupplyconfig',
            name='managed_channels',
            field=models.ManyToManyField(blank=True, to='marketmanager.Channel', verbose_name='Channels'),
        ),
        migrations.AlterField(
            model_name='managedsupplyconfig',
            name='managed_debug_channels',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on SupplyConfigs that _dont_ notify. Because their Configs didnt Meet/Breach.', related_name='+', to='marketmanager.Channel', verbose_name='Debug Channels'),
        ),
        migrations.AlterField(
            model_name='managedsupplyconfig',
            name='managed_debug_webhooks',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on Supplyonfigs that _dont_ notify. Because their Configs didnt Meet/Breach.', related_name='+', to='marketmanager.Webhook', verbose_name='Debug Webhook'),
        ),
        migrations.AlterField(
            model_name='managedsupplyconfig',
            name='managed_region',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveRegion', verbose_name='Region'),
        ),
        migrations.AlterField(
            model_name='managedsupplyconfig',
            name='managed_solar_system',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveSolarSystem', verbose_name='Solar System'),
        ),
        migrations.AlterField(
            model_name='managedsupplyconfig',
            name='managed_structure',
            field=models.ManyToManyField(blank=True, to='marketmanager.Structure', verbose_name='Structure'),
        ),
        migrations.AlterField(
            model_name='managedsupplyconfig',
            name='managed_structure_type',
            field=models.ManyToManyField(blank=True, help_text='Filter by structure Type/Size/Docking (ie, forts/keeps for cap fuel)', to='eveuniverse.EveType', verbose_name='Structure Type Filter'),
        ),
        migrations.AlterField(
            model_name='managedsupplyconfig',
            name='managed_webhooks',
            field=models.ManyToManyField(blank=True, to='marketmanager.Webhook', verbose_name='Webhooks'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='channels',
            field=models.ManyToManyField(blank=True, to='marketmanager.Channel', verbose_name='Channels'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='debug_channels',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on PriceConfigs that _dont_ notify. Because their Configs didnt Meet/Breach.', related_name='+', to='marketmanager.Channel', verbose_name='Debug Channels'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='debug_webhooks',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on PriceConfigs that _dont_ notify. Because their Configs didnt Meet/Breach.', related_name='+', to='marketmanager.Webhook', verbose_name='Debug Webhook'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='eve_group',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveGroup', verbose_name='EVE Inventory Group'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='eve_market_group',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveMarketGroup', verbose_name='EVE Market Group'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='eve_type',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveType', verbose_name='EVE Type'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='region',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveRegion', verbose_name='Region'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='solar_system',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveSolarSystem', verbose_name='Solar System'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='structure',
            field=models.ManyToManyField(blank=True, to='marketmanager.Structure', verbose_name='Structure'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='structure_type',
            field=models.ManyToManyField(blank=True, help_text='Filter by structure Type/Size/Docking (ie, forts/keeps for cap fuel)', related_name='+', to='eveuniverse.EveType', verbose_name='Structure Type Filter'),
        ),
        migrations.AlterField(
            model_name='priceconfig',
            name='webhooks',
            field=models.ManyToManyField(blank=True, to='marketmanager.Webhook', verbose_name='Webhooks'),
        ),
        migrations.AlterField(
            model_name='privateconfig',
            name='valid_corporations',
            field=models.ManyToManyField(blank=True, to='eveonline.EveCorporationInfo', verbose_name='Valid Corporation Markets for this Token'),
        ),
        migrations.AlterField(
            model_name='privateconfig',
            name='valid_structures',
            field=models.ManyToManyField(blank=True, to='marketmanager.Structure', verbose_name='Valid Structure Markets for this Token'),
        ),
        migrations.AlterField(
            model_name='publicconfig',
            name='fetch_regions',
            field=models.ManyToManyField(to='eveuniverse.EveRegion', verbose_name='Fetch Regions'),
        ),
        migrations.AlterField(
            model_name='statisticsconfig',
            name='calculate_regions',
            field=models.ManyToManyField(to='eveuniverse.EveRegion', verbose_name='TypeStatistics Calculation Regions'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='channels',
            field=models.ManyToManyField(blank=True, to='marketmanager.Channel', verbose_name='Channels'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='debug_channels',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on SupplyConfigs that _dont_ notify. Because their Configs didnt Meet/Breach.', related_name='+', to='marketmanager.Channel', verbose_name='Debug Channels'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='debug_webhooks',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on SupplyConfigs that _dont_ notify. Because their Configs didnt Meet/Breach.', related_name='+', to='marketmanager.Webhook', verbose_name='Debug Webhook'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='region',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveRegion', verbose_name='Region'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='solar_system',
            field=models.ManyToManyField(blank=True, to='eveuniverse.EveSolarSystem', verbose_name='Solar System'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='structure',
            field=models.ManyToManyField(blank=True, to='marketmanager.Structure', verbose_name='Structure'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='structure_type',
            field=models.ManyToManyField(blank=True, help_text='Filter by structure Type/Size/Docking (ie, forts/keeps for cap fuel)', related_name='+', to='eveuniverse.EveType', verbose_name='Structure Type Filter'),
        ),
        migrations.AlterField(
            model_name='supplyconfig',
            name='webhooks',
            field=models.ManyToManyField(blank=True, to='marketmanager.Webhook', verbose_name='Webhooks'),
        ),
    ]
