# Generated by Django 4.0.6 on 2022-08-02 11:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0029_managedwatchconfig_managed_buy_order_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Channel',
            fields=[
                ('name', models.CharField(max_length=100)),
                ('id', models.BigIntegerField(primary_key=True, serialize=False)),
            ],
            options={
                'verbose_name': 'Channel',
                'verbose_name_plural': 'Channels',
                'default_permissions': (),
            },
        ),
        migrations.AddField(
            model_name='managedwatchconfig',
            name='managed_channels',
            field=models.ManyToManyField(blank=True, to='marketmanager.channel', verbose_name='Channels'),
        ),
        migrations.AddField(
            model_name='managedwatchconfig',
            name='managed_debug_channels',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on WatchConfigs that _dont_ notify. Because their Configs didnt Meet/Breach.', related_name='managed_debug_channels', to='marketmanager.channel', verbose_name='Debug Channels'),
        ),
        migrations.AddField(
            model_name='watchconfig',
            name='channels',
            field=models.ManyToManyField(blank=True, to='marketmanager.channel', verbose_name='Channels'),
        ),
        migrations.AddField(
            model_name='watchconfig',
            name='debug_channels',
            field=models.ManyToManyField(blank=True, help_text='Primarily for Testing/Debugging Purposes. This webhook will receive updates on WatchConfigs that _dont_ notify. Because their Configs didnt Meet/Breach.', related_name='debug_channels', to='marketmanager.channel', verbose_name='Debug Channels'),
        ),
    ]
