# Generated by Django 4.0.6 on 2022-09-16 14:21

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0007_evetype_description'),
        ('marketmanager', '0037_alter_general_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='structure',
            name='eve_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveuniverse.evetype', verbose_name='Type'),
        ),
        migrations.AlterField(
            model_name='structure',
            name='solar_system',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveuniverse.evesolarsystem', verbose_name='Solar System'),
        ),
    ]
