# Generated by Django 4.0.3 on 2022-03-19 06:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0021_typestatistics_new_eden'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='typestatistics',
            name='EveTypeEveRegionTypeStatistic',
        ),
    ]
