<form class="d-flex" role="search" action="{% url 'marketmanager:marketbrowser' %}" method="get">
    <div class="form-group">
        <input type="text" id="search" value class="form-control" placeholder="Search" />
    </div>
</form>
