# Generated by Django 4.0.10 on 2023-10-19 06:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0047_alter_structure_eve_type_alter_supplyconfig_eve_type_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='channel',
            options={'verbose_name': 'Channel', 'verbose_name_plural': 'Channels'},
        ),
        migrations.AlterModelOptions(
            name='managedsupplyconfig',
            options={'verbose_name': 'Managed Supply Config'},
        ),
        migrations.AlterModelOptions(
            name='priceconfig',
            options={},
        ),
        migrations.AlterModelOptions(
            name='privateconfig',
            options={'verbose_name': 'Private Market Configuration'},
        ),
        migrations.AlterModelOptions(
            name='publicconfig',
            options={'verbose_name': 'Public Market Configuration'},
        ),
        migrations.AlterModelOptions(
            name='statisticsconfig',
            options={'verbose_name': 'TypeStatistics Calculation Configuration'},
        ),
        migrations.AlterModelOptions(
            name='structure',
            options={},
        ),
        migrations.AlterModelOptions(
            name='supplyconfig',
            options={},
        ),
        migrations.AlterModelOptions(
            name='webhook',
            options={},
        ),
    ]
