# Generated by Django 4.0.3 on 2022-03-19 06:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0020_alter_order_duration_alter_order_price_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='typestatistics',
            name='new_eden',
            field=models.BooleanField(default=False, verbose_name='New Eden Wide'),
        ),
    ]
